@@ -6,7 +6,7 @@ Applify - Write object oriented scripts with ease
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 DESCRIPTION
 
@@ -26,7 +26,7 @@ are define directly in the script file and not in a module.
     documentation __FILE__;
     version 1.23;
 
-    sub app::generate_exit_value => sub {
+    sub generate_exit_value => sub {
         return int rand 100;
     };
 
@@ -63,7 +63,8 @@ This method is basically the code block given to L</app>.
 
 =item * Other methods
 
-Other methods must be defined in the C<app::> namespace.
+Other methods defined in the script file will be accesible from C<$self>
+inside C<app{}>.
 
 =item * _script()
 
@@ -92,7 +93,7 @@ use constant SUB_NAME_IS_AVAILABLE
      : eval 'use Sub::Name; 1'        ? 1
      :                                  0;
 
-our $VERSION = eval '0.02';
+our $VERSION = eval '0.03';
 our $PERLDOC = 'perldoc';
 my $ANON = 1;
 
@@ -360,12 +361,10 @@ sub _generate_application_class {
         package $application_class;
         use base qw/ @$extends /;
         1;
-    ] or die "Failed to generate class: $@";
+    ] or die "Failed to generate applicatin class: $@";
 
     {
         no strict 'refs';
-        my $methods = \%{'app::'};
-
         __new_sub "$application_class\::new" => sub { my $class = shift; bless shift, $class } unless(grep { $_->can('new') } @$extends);
         __new_sub "$application_class\::_script" => sub { $self };
         __new_sub "$application_class\::run" => sub {
@@ -380,20 +379,24 @@ sub _generate_application_class {
             return $app->$code(@extra);
         };
 
+        for('app', $self->{'caller'}[0]) {
+            my $ns = \%{"$_\::"};
+
+            for my $name (keys %$ns) {
+                $self->{'keep_subs'}{$name} and next;
+                my $code = *{$ns->{$name}}{'CODE'} or next;
+                my $fqn = join '::', $application_class, $name;
+                __new_sub $fqn => $code;
+                delete $ns->{$name}; # may be a bit too destructive?
+            }
+        }
+
         for my $option (@{ $self->{'options'} }) {
             my $name = $option->{'name'};
             my $fqn = join '::', $application_class, $option->{'name'};
             __new_sub $fqn => sub { @_ == 2 and $_[0]->{$name} = $_[1]; $_[0]->{$name} };
             push @required, $name if($option->{'required'});
         }
-
-        
-        for my $name (keys %$methods) {
-            my $code = *{$methods->{$name}}{'CODE'} or next;
-            my $fqn = join '::', $application_class, $name;
-            __new_sub $fqn => $code;
-            delete $methods->{$name}; # may be a bit too destructive?
-        }
     }
 
     return $application_class;
@@ -553,17 +556,21 @@ sub import {
     my $class = shift;
     my @caller = CORE::caller(1);
     my $self = $class->new({ caller => \@caller });
+    my $ns = $caller[0] .'::';
 
     strict->import;
     warnings->import;
 
     no strict 'refs';
+    for my $name (keys %$ns) {
+        $self->{'keep_subs'}{$name} = 1;
+    }
+
     no warnings 'redefine'; # need to allow redefine when loading a new app
     *{"$caller[0]\::app"} = sub (&) { $self->app(@_) };
     *{"$caller[0]\::option"} = sub { $self->option(@_) };
     *{"$caller[0]\::version"} = sub { $self->version(@_) };
     *{"$caller[0]\::documentation"} = sub { $self->documentation(@_) };
-    *{"$caller[0]\::method"} = sub { $self->method(@_) };
     *{"$caller[0]\::extends"} = sub { $self->extends(@_) };
 }
 
